@@ -2,7 +2,7 @@ mod usnjrnl_reader;
 pub use usnjrnl_reader::UsnJrnlReader;
 
 mod usn_record;
-pub use usn_record::CommonUsnRecord;
+pub use usn_record::{CommonUsnRecord, UsnRecordData};
 
 mod usn_reader_error;
 pub use usn_reader_error::UsnReaderError;
